@@ -5,5 +5,5 @@ def endpoint(service: str = '') -> str:
     :param service: The path to the services to join with the request base.
     :return: A string with the URL.
     """
-    base_url = '<script>document.write(window.location.href).replace(/\\/$/, "");</script>'
+    base_url = '<script>document.write(window.location.href.replace(/\\/$/, ""));</script>'
     return base_url + service if service.startswith('/') else base_url + '/' + service
